==> order-center-api-3.2.1-CLOUD-DEV-20240412.125155-12-sources.jar: com/tydic/dyc/oc/service/domainservice/bo/UocCreateOrderServiceReqBo.java <==
package com.tydic.dyc.oc.service.domainservice.bo;

import com.alibaba.fastjson.JSONObject;
import com.tydic.dyc.base.bo.BaseReqBo;
import com.tydic.dyc.oc.service.common.bo.UocBaseExtParallelBo;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 描述：
 *
 * @author tgy
 * @date 2022/2/13 20:54
 */
@EqualsAndHashCode(callSuper = true)
@Data
public class UocCreateOrderServiceReqBo extends BaseReqBo {

    private static final long serialVersionUID = 7344454593346320509L;

    /**订单id，外部传入，使用外部的*/
    private Long orderId;

    /**
     * 销售总金额
     */
    private BigDecimal totalSaleFee;

    /**
     * 采购总金额
     */
    private BigDecimal totalPurchaseFee;

    /**
     * 运费
     */
    private BigDecimal totalTransFee;

    /**
     * 备注
     */
    private String remark;

    /**
     * 采购方账套id
     */
    private String purAccount;

    /**
     * 采购方账套名称
     */
    private String purAccountName;

    /**
     * 采购方联系人
     */
    private String purContactName;

    /**
     * 采购方联系人电话
     */
    private String purMobile;

    /**
     * 需方联系人名称
     */
    private String purNeedName;

    /**
     * 需方联系电话
     */
    private String purNeedMobile;

    /**
     * 送货时间
     */
    private Date sendTime;

    /**
     * 订单级别 1 个人订单  2 企业订单，默认个人订单
     */
    private Integer orderLevel;

    /**
     * 是否同步创建销售单及其相关信息，默认false
     */
    private Boolean createSaleOrder;

    /**
     * 订单名称
     */
    private String orderName;

    /**
     * 下单系统
     */
    private String orderSystem;

    /**
     * 订单类型 :1.采购电商
     */
    private Integer orderType;

    /**
     * 订单说明
     */
    private String orderDesc;

    /**
     * 实付金额
     */
    private BigDecimal usedFee;

    /**
     * 实付积分
     */
    private BigDecimal usedIntegral;

//    租户ID
//    private String tenantId;

    /**
     * 商品信息
     */
    private List<UocCreateOrderServiceReqCommodityBo> orderItems;

    /**
     * 发票信息
     */
    private UocCreateOrderServiceReqInvoiceBo uocOrdInvoice;

    /**
     * 运营方信息
     */
    private UocCreateOrderServiceReqProfessionalBo operating;

//    /**
//     * 支付配置，当需要同步创建销售单时(createSaleOrder为true)，必传（从结算基于采购方和运营方查询）
//     */
//    private List<UocCreateOrderServiceReqPayConfSupBo> payConfigList;
    /**
     * 供应商信息
     */
    private List<UocSupplierInfoBo> supplierBos;

    /**
     * 协议信息
     */
    private List<UocCreateOrderServiceReqArgPayConfSupBo> agrPayConfigList;

    /**
     * 收货人地址信息
     */
    private UocCreateOrderServiceReqAddressBo receiverAddress;

    /**
     * 发票邮寄信息
     */
    private UocCreateOrderServiceReqAddressBo invoiceAddress;

    /**
     * 订单附件信息
     */
    private List<UocCreateOrderServiceReqAccessoryBo> accessoryList;

//    /**
//     * 订单纵向扩展数据
//     */
//    private List<UocBaseExtParallelBo> orderParallelExtList;

//    /**
//     * 业务外参数（签约单信息或其他）
//     */
//    private JSONObject jsonObj;

//    /**
//     * 订单创建结果 0创建中，1成功，2失败
//     */
//    private Integer createdResult;

    /**
     * 当前登录用户id
     */
    private Long userId;
    /**
     * 当前登录用户名称
     */
    private String name;
    /**
     * 当前登录用户账号名
     */
    private String userName;
    /**
     * 当前登录用户机构id
     */
    private Long orgId;
    /**
     * 当前登录用户机构名称
     */
    private String orgName;
    /**
     * 当前登录用户公司id
     */
    private Long companyId;
    /**
     * 当前登录用户公司名称
     */
    private String companyName;
    /**
     * 当前登录用户机构树路径
     */
    private String orgPath;
    /**
     * 用户类型：1 外部个人 2 外部企业 3内部个人 4 内部企业
     */
    private String userType;
    
    //议价单id
    private Long bargainingId;
    
    //议价单编号
    private String bargainingNo;

}

==> order-center-api-3.2.2-CLOUD-DEV-20240807.070522-52-sources.jar: com/tydic/dyc/oc/service/domainservice/bo/UocCreateOrderServiceReqBo.java <==
package com.tydic.dyc.oc.service.domainservice.bo;

import com.tydic.dyc.base.bo.BaseReqBo;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 描述：
 *
 * @author tgy
 * @date 2022/2/13 20:54
 */
@EqualsAndHashCode(callSuper = true)
@Data
public class UocCreateOrderServiceReqBo extends BaseReqBo {

    private static final long serialVersionUID = 7344454593346320509L;

    /**订单id，外部传入，使用外部的*/
    private Long orderId;

    /**
     * 销售总金额
     */
    private BigDecimal totalSaleFee;

    /**
     * 采购总金额
     */
    private BigDecimal totalPurchaseFee;

    /**
     * 运费
     */
    private BigDecimal totalTransFee;

    /**
     * 备注
     */
    private String remark;

    /**
     * 采购方账套id
     */
    private String purAccount;

    /**
     * 采购方账套名称
     */
    private String purAccountName;

    /**
     * 采购方联系人
     */
    private String purContactName;

    /**
     * 采购方联系人电话
     */
    private String purMobile;

    /**
     * 需方联系人名称
     */
    private String purNeedName;

    /**
     * 需方联系电话
     */
    private String purNeedMobile;

    /**
     * 送货时间
     */
    private Date sendTime;

    /**
     * 订单级别 1 个人订单  2 企业订单，默认个人订单
     */
    private Integer orderLevel;

    /**
     * 是否同步创建销售单及其相关信息，默认false
     */
    private Boolean createSaleOrder;

    /**
     * 订单名称
     */
    private String orderName;

    /**
     * 下单系统
     */
    private String orderSystem;

    /**
     * 订单类型 :1.采购电商
     */
    private Integer orderType;

    /**
     * 订单说明
     */
    private String orderDesc;

    /**
     * 实付金额
     */
    private BigDecimal usedFee;

    /**
     * 实付积分
     */
    private BigDecimal usedIntegral;

//    租户ID
//    private String tenantId;

    /**
     * 商品信息
     */
    private List<UocCreateOrderServiceReqCommodityBo> orderItems;

    /**
     * 发票信息
     */
    private UocCreateOrderServiceReqInvoiceBo uocOrdInvoice;

    /**
     * 运营方信息
     */
    private UocCreateOrderServiceReqProfessionalBo operating;

//    /**
//     * 支付配置，当需要同步创建销售单时(createSaleOrder为true)，必传（从结算基于采购方和运营方查询）
//     */
//    private List<UocCreateOrderServiceReqPayConfSupBo> payConfigList;
    /**
     * 供应商信息
     */
    private List<UocSupplierInfoBo> supplierBos;

    /**
     * 协议信息
     */
    private List<UocCreateOrderServiceReqArgPayConfSupBo> agrPayConfigList;

    /**
     * 收货人地址信息
     */
    private UocCreateOrderServiceReqAddressBo receiverAddress;

    /**
     * 发票邮寄信息
     */
    private UocCreateOrderServiceReqAddressBo invoiceAddress;

    /**
     * 订单附件信息
     */
    private List<UocCreateOrderServiceReqAccessoryBo> accessoryList;

//    /**
//     * 订单纵向扩展数据
//     */
//    private List<UocBaseExtParallelBo> orderParallelExtList;

//    /**
//     * 业务外参数（签约单信息或其他）
//     */
//    private JSONObject jsonObj;

//    /**
//     * 订单创建结果 0创建中，1成功，2失败
//     */
//    private Integer createdResult;

    /**
     * 当前登录用户id
     */
    private Long userId;
    /**
     * 当前登录用户名称
     */
    private String name;
    /**
     * 当前登录用户账号名
     */
    private String userName;
    /**
     * 当前登录用户机构id
     */
    private Long orgId;
    /**
     * 当前登录用户机构名称
     */
    private String orgName;
    /**
     * 当前登录用户公司id
     */
    private Long companyId;
    /**
     * 当前登录用户公司名称
     */
    private String companyName;
    /**
     * 当前登录用户机构树路径
     */
    private String orgPath;
    /**
     * 用户类型：1 外部个人 2 外部企业 3内部个人 4 内部企业
     */
    private String userType;
    
    //议价单id
    private Long bargainingId;
    
    //议价单编号
    private String bargainingNo;


    //京能新增参数开始
    /**
     * 是否需要保存 oa 审批结果  0不需要 1 需要
     */
    private Integer saveOaApprovalResult = 0;

    /**
     * 是否需要补充计划 0不需要 1 需要
     */
    private Integer requireSupplementalPlan = 0;

    /**
     * 费用承担单位id
     */
    private Long costBearingOrgId;
    /**
     * 费用承担单位公司id
     */
    private Long costBearingCompanyId;
    /**
     * 费用承担单位名称
     */
    private String costBearingOrgName;
    /**
     * 费用承担单位机构树路径
     */
    private String costBearingOrgPath;
    /**
     * 成本扣减单位 id
     */
    private Long reduceOrgId;
    /**
     * 专区类型 1-工业品；2-办公用品
     */
    private Integer areaType;

    /**
     * 是否校验额度 0否 1是
     */
    private Integer isReduceQuota = 1;
    //京能新增参数结束
    /**
     * 是否跳过发货和到货确认
     */
    private Integer isAgrIgnoreArrive;
    /**
     * 是否物料下单
     */
    private Integer isMatOrder;

    /**
     * 是否需要开票 1是 0否
     */
    private Integer isDealInvoice;
}
